import {margin, height, width} from "./constants.js";


export function addLegend(svg, labelsSet, color) {
    const labels = Array.from(labelsSet)
    const legend = svg
        .selectAll(".legend-group")
        .data([null])
        .enter()
        .append("g")
        .attr("class", "legend-group")
        .attr("transform", `translate(${width - 200}, 0)`)
        .selectAll(".legend-item")
        .data(labels)
        .enter()
        .append("g")
        .attr("class", "legend-item")
        .attr("transform", (d, i) => `translate(0, ${i * 20})`)
        .each(function(d, i) {
            const group = d3.select(this);

            group.append("rect")
                .attr("width", 10)
                .attr("height", 10)
                .attr("fill", color(d))
                .on("mouseover", () => {
                    svg.selectAll(".line").classed("highlighted", line => line === d);
                })
                .on("mouseout", () => {
                    svg.selectAll(".line").classed("highlighted", false);
                });

            group.append("text")
                .attr("x", 20)
                .attr("y", 10)
                .attr("text-anchor", "start")
                .style("text-transform", "capitalize")
                .text(d);
        });

    const legendBBox = svg.select(".legend-group").node().getBBox()

    svg.select(".legend-group")
        .insert("rect", ":first-child")
        .attr("width", 140)
        .attr("height", labels.length*20+20)
        .attr("transform", `translate(-10, -10)`)
        .attr("fill", "white")
        .attr("fill-opacity", 0.7)
        .attr("stroke", "#c6c6c6")
        .attr("stroke-width", 2)
        .attr("rx", 5)
        .attr("ry", 5)
}

export function addSvg(containerSelector) {
    return d3.select(containerSelector)
        .append("svg")
        .attr("width", "100%")
        .attr("height", "100%")
        .append("g")
        .attr("transform", `translate(${margin.left + 30},${margin.top - 10})`)
}